@@ -44,8 +44,10 @@ def version():
         - 修复extract_pdf出错的bug: PdfFileReader(pdfFile, strict=False)
         - 返回页码p不能为0的报错信息
         - .adminclass增加注释和使用说明        # 2.4.4
+        - bulk_delete增加权限控制        # 2.4.5
+        - order_by_order_type_ls修复为[""]的时候出现的bug
     """
-    v = "2.4.4"     # 当前: 2.4.4
+    v = "2.4.5"  # 当前: 2.4.5
     return v
 
 
@@ -55,7 +57,6 @@ except Exception as e:
     warn('导入django失败? --- ' + str(e))
 
 try:
-    from .myFIelds import AliasField        # 这个只能在这里引用, 不然`adminclass`报错
+    from .myFIelds import AliasField  # 这个只能在这里引用, 不然`adminclass`报错
 except Exception as e:
     warn('导入`AliasField`失败? --- ' + str(e))
-
