@@ -56,6 +56,10 @@ def get_list(query_dc, key):
 
     if isinstance(ret, str):
         ret = [ret]
+
+    if ret == ['']:
+        ret = []
+
     return ret
 
 
